Class: Google::Apis::DigitalassetlinksV1::BulkCheckResponse
- Inherits:
-
Object
- Object
- Google::Apis::DigitalassetlinksV1::BulkCheckResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/digitalassetlinks_v1/classes.rb,
lib/google/apis/digitalassetlinks_v1/representations.rb,
lib/google/apis/digitalassetlinks_v1/representations.rb
Overview
Response for BulkCheck call. Results are sent in a list in the same order in which they were sent. Individual check errors are described in the appropriate check_results entry. If the entire call fails, the response will include a bulk_error_code field describing the error.
Instance Attribute Summary collapse
-
#bulk_error_code ⇒ String
Error code for the entire request.
-
#check_results ⇒ Array<Google::Apis::DigitalassetlinksV1::CheckResponse>
List of results for each check request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BulkCheckResponse
constructor
A new instance of BulkCheckResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BulkCheckResponse
Returns a new instance of BulkCheckResponse.
151 152 153 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 151 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bulk_error_code ⇒ String
Error code for the entire request. Present only if the entire request failed.
Individual check errors will not trigger the presence of this field.
Corresponds to the JSON property bulkErrorCode
143 144 145 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 143 def bulk_error_code @bulk_error_code end |
#check_results ⇒ Array<Google::Apis::DigitalassetlinksV1::CheckResponse>
List of results for each check request. Results are returned in the same order
in which they were sent in the request.
Corresponds to the JSON property checkResults
149 150 151 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 149 def check_results @check_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
156 157 158 159 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 156 def update!(**args) @bulk_error_code = args[:bulk_error_code] if args.key?(:bulk_error_code) @check_results = args[:check_results] if args.key?(:check_results) end |