Class: Google::Apis::DigitalassetlinksV1::BulkCheckRequest
- Inherits:
-
Object
- Object
- Google::Apis::DigitalassetlinksV1::BulkCheckRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/digitalassetlinks_v1/classes.rb,
lib/google/apis/digitalassetlinks_v1/representations.rb,
lib/google/apis/digitalassetlinks_v1/representations.rb
Overview
Message used to check for the existence of multiple digital asset links within a single RPC.
Instance Attribute Summary collapse
-
#default_relation ⇒ String
If specified, will be used in any given template statement that doesn’t specify a relation.
-
#default_source ⇒ Google::Apis::DigitalassetlinksV1::Asset
Uniquely identifies an asset.
-
#default_target ⇒ Google::Apis::DigitalassetlinksV1::Asset
Uniquely identifies an asset.
-
#return_relation_extensions ⇒ Boolean
(also: #return_relation_extensions?)
Same configuration as in CheckRequest; all statement checks will use the same configuration.
-
#statements ⇒ Array<Google::Apis::DigitalassetlinksV1::StatementTemplate>
List of statements to check.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BulkCheckRequest
constructor
A new instance of BulkCheckRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BulkCheckRequest
Returns a new instance of BulkCheckRequest.
118 119 120 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 118 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_relation ⇒ String
If specified, will be used in any given template statement that doesn’t
specify a relation.
Corresponds to the JSON property defaultRelation
88 89 90 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 88 def default_relation @default_relation end |
#default_source ⇒ Google::Apis::DigitalassetlinksV1::Asset
Uniquely identifies an asset. A digital asset is an identifiable and
addressable online entity that typically provides some service or content.
Examples of assets are websites, Android apps, Twitter feeds, and Plus Pages.
Corresponds to the JSON property defaultSource
95 96 97 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 95 def default_source @default_source end |
#default_target ⇒ Google::Apis::DigitalassetlinksV1::Asset
Uniquely identifies an asset. A digital asset is an identifiable and
addressable online entity that typically provides some service or content.
Examples of assets are websites, Android apps, Twitter feeds, and Plus Pages.
Corresponds to the JSON property defaultTarget
102 103 104 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 102 def default_target @default_target end |
#return_relation_extensions ⇒ Boolean Also known as: return_relation_extensions?
Same configuration as in CheckRequest; all statement checks will use the same
configuration.
Corresponds to the JSON property returnRelationExtensions
108 109 110 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 108 def return_relation_extensions @return_relation_extensions end |
#statements ⇒ Array<Google::Apis::DigitalassetlinksV1::StatementTemplate>
List of statements to check. For each statement, you can omit a field if the
corresponding default_* field below was supplied. Minimum 1 statement; maximum
1,000 statements. Any additional statements will be ignored.
Corresponds to the JSON property statements
116 117 118 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 116 def statements @statements end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
123 124 125 126 127 128 129 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 123 def update!(**args) @default_relation = args[:default_relation] if args.key?(:default_relation) @default_source = args[:default_source] if args.key?(:default_source) @default_target = args[:default_target] if args.key?(:default_target) @return_relation_extensions = args[:return_relation_extensions] if args.key?(:return_relation_extensions) @statements = args[:statements] if args.key?(:statements) end |