Class: Google::Apis::DigitalassetlinksV1::CheckResponse
- Inherits:
-
Object
- Object
- Google::Apis::DigitalassetlinksV1::CheckResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/digitalassetlinks_v1/classes.rb,
lib/google/apis/digitalassetlinks_v1/representations.rb,
lib/google/apis/digitalassetlinks_v1/representations.rb
Overview
Response message for the CheckAssetLinks call.
Instance Attribute Summary collapse
-
#debug_string ⇒ String
Human-readable message containing information intended to help end users understand, reproduce and debug the result.
-
#error_code ⇒ Array<String>
Error codes that describe the result of the Check operation.
-
#linked ⇒ Boolean
(also: #linked?)
Set to true if the assets specified in the request are linked by the relation specified in the request.
-
#max_age ⇒ String
From serving time, how much longer the response should be considered valid barring further updates.
-
#relation_extensions ⇒ Array<Hash<String,Object>>
Statements may specify relation level extensions/payloads to express more details when declaring permissions to grant from the source asset to the target asset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CheckResponse
constructor
A new instance of CheckResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CheckResponse
Returns a new instance of CheckResponse.
238 239 240 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 238 def initialize(**args) update!(**args) end |
Instance Attribute Details
#debug_string ⇒ String
Human-readable message containing information intended to help end users
understand, reproduce and debug the result. The message will be in English and
we are currently not planning to offer any translations. Please note that no
guarantees are made about the contents or format of this string. Any aspect of
it may be subject to change without notice. You should not attempt to
programmatically parse this data. For programmatic access, use the error_code
field below.
Corresponds to the JSON property debugString
205 206 207 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 205 def debug_string @debug_string end |
#error_code ⇒ Array<String>
Error codes that describe the result of the Check operation. NOTE: Error codes
may be populated even when linked is true. The error codes do not
necessarily imply that the request failed, but rather, specify any errors
encountered in the statements file(s) which may or may not impact whether the
server determines the requested source and target to be linked.
Corresponds to the JSON property errorCode
214 215 216 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 214 def error_code @error_code end |
#linked ⇒ Boolean Also known as: linked?
Set to true if the assets specified in the request are linked by the relation
specified in the request.
Corresponds to the JSON property linked
220 221 222 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 220 def linked @linked end |
#max_age ⇒ String
From serving time, how much longer the response should be considered valid
barring further updates. REQUIRED
Corresponds to the JSON property maxAge
227 228 229 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 227 def max_age @max_age end |
#relation_extensions ⇒ Array<Hash<String,Object>>
Statements may specify relation level extensions/payloads to express more
details when declaring permissions to grant from the source asset to the
target asset. When requested, the API will return relation_extensions
specified in any and all statements linking the requested source and target
assets by the relation specified in the request.
Corresponds to the JSON property relationExtensions
236 237 238 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 236 def relation_extensions @relation_extensions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
243 244 245 246 247 248 249 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 243 def update!(**args) @debug_string = args[:debug_string] if args.key?(:debug_string) @error_code = args[:error_code] if args.key?(:error_code) @linked = args[:linked] if args.key?(:linked) @max_age = args[:max_age] if args.key?(:max_age) @relation_extensions = args[:relation_extensions] if args.key?(:relation_extensions) end |