Class: Google::Apis::DigitalassetlinksV1::StatementTemplate
- Inherits:
-
Object
- Object
- Google::Apis::DigitalassetlinksV1::StatementTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/digitalassetlinks_v1/classes.rb,
lib/google/apis/digitalassetlinks_v1/representations.rb,
lib/google/apis/digitalassetlinks_v1/representations.rb
Overview
A single statement to check in a bulk call using BulkCheck. See CheckRequest for details about each field.
Instance Attribute Summary collapse
-
#relation ⇒ String
The relationship being asserted between the source and target.
-
#source ⇒ Google::Apis::DigitalassetlinksV1::Asset
Uniquely identifies an asset.
-
#target ⇒ Google::Apis::DigitalassetlinksV1::Asset
Uniquely identifies an asset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StatementTemplate
constructor
A new instance of StatementTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StatementTemplate
Returns a new instance of StatementTemplate.
385 386 387 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 385 def initialize(**args) update!(**args) end |
Instance Attribute Details
#relation ⇒ String
The relationship being asserted between the source and target. If omitted, you
must specify a BulkCheckRequest.default_relation value to use here.
Corresponds to the JSON property relation
369 370 371 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 369 def relation @relation end |
#source ⇒ Google::Apis::DigitalassetlinksV1::Asset
Uniquely identifies an asset. A digital asset is an identifiable and
addressable online entity that typically provides some service or content.
Examples of assets are websites, Android apps, Twitter feeds, and Plus Pages.
Corresponds to the JSON property source
376 377 378 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 376 def source @source end |
#target ⇒ Google::Apis::DigitalassetlinksV1::Asset
Uniquely identifies an asset. A digital asset is an identifiable and
addressable online entity that typically provides some service or content.
Examples of assets are websites, Android apps, Twitter feeds, and Plus Pages.
Corresponds to the JSON property target
383 384 385 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 383 def target @target end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
390 391 392 393 394 |
# File 'lib/google/apis/digitalassetlinks_v1/classes.rb', line 390 def update!(**args) @relation = args[:relation] if args.key?(:relation) @source = args[:source] if args.key?(:source) @target = args[:target] if args.key?(:target) end |